/** @(#)ai2c.h       <07-Jul-2016 13:54:27 Bob Paddock>
 *  Last Time-stamp: <20-Jul-2016 08:34:11 bob p>
 *
 *  \file ai2c.h
 *  \brief  i2c for MKL27, intended for use with Freescale/NXP Accelerometer.
 *
 *      Purpose:        General I2C handler, created using the flowchart example
 *                      included in the I2C chapter of the User Manual.
 *                      Only Master is implemented as we are never a slave.
 *  See AN4342 and "Typical I2C Interrupt Routine" in KL27 Reference Manual.
 *
 * Use at own risk the underlying hardware of the KL43/KL27 I2C Double Buffered hardware is broken.
 */

/*lint -save -e755 -e756 Disable warning(s), this file only, global macro/typedef 'Symbol' (Location) not referenced */

#ifndef _AI2C_H_
#define _AI2C_H_ (1)

#ifdef  DEFINE_SPACE_AI2C_H
#define EXTERN_AI2C
#else
#define EXTERN_AI2C extern
#endif

#if defined(__cplusplus) && __cplusplus
 extern "C" {
#endif

#define I2C_TXRX        (2U)
#define I2C_TX          (0U) /* ORed with slave address lowest bit */
#define I2C_RX          (1U) /* ORed with slave address lowest bit */

    void i2c_init( uint_fast16_t const channel_u16, uint8_t const mult, uint8_t const icr );
    void i2c_master( uint16_t const channel_u16, uint8_t const mode_u8, uint16_t const slave_adr_u16, uint16_t const r_len_u16, uint8_t *r_ptr_u8, uint16_t const w_len_u16, uint8_t const *w_ptr_u8 );

#if defined(__cplusplus) && __cplusplus
 }
#endif

#endif /* _AI2C_H_ */

/*lint -restore */
